@@ -281,6 +281,7 @@ def test_accession_post_analysis(mocker, mock_accession):
         "pipeline_version": "1.2.3",
         "award": "U24HG009397",
         "lab": "/labs/encode-processing-pipeline/",
+        "quality_standard": "/quality-standards/bar/",
     }
 
 
@@ -642,6 +643,7 @@ def test_accession_steps_matches_with_force(
     )
     mocker.patch.object(mock_accession, "accession_step")
     mocker.patch.object(mock_accession, "post_analysis")
+    mocker.patch.object(mock_accession, "record_run")
     mock_accession.accession_steps(force=True)
     assert "continuing accessioning" in caplog.text
     mock_accession.accession_step.assert_called()
